//
//  $Id: spi.c 173 2008-10-19 01:15:45Z jcw $
//  $Revision: 173 $
//  $Author: jcw $
//  $Date: 2008-10-18 21:15:45 -0400 (Sat, 18 Oct 2008) $
//  $HeadURL: http://tinymicros.com/svn_public/arm/lpc2148_demo/trunk/uip/hardware/spi.c $
//

#include "FreeRTOS.h"

#include "../uip/uipopt.h"

#include "spi.h"

//
//
//
void spiInit (void)
{
  U32 spsr;

  //
  //  Setup SCK0, MISO0 and MOSI0.  SSEL0 (P0.7) is GPIO, as is P0.22 (/RESET)
  //
  PCB_PINSEL0 = (PCB_PINSEL0 & ~(PCB_PINSEL0_P04_MASK | PCB_PINSEL0_P05_MASK | PCB_PINSEL0_P06_MASK | PCB_PINSEL0_P07_MASK)) | (PCB_PINSEL0_P04_SCK0 | PCB_PINSEL0_P05_MISO0 | PCB_PINSEL0_P06_MOSI0 | PCB_PINSEL0_P07_GPIO);
  PCB_PINSEL1 = (PCB_PINSEL1 & ~PCB_PINSEL1_P022_MASK) | PCB_PINSEL1_P022_GPIO;

  //
  //  Set P0.7, P0.22 as outputs
  //
  GPIO0_FIODIR |= (GPIO_IO_P7 | GPIO_IO_P22);

  SCB_PCONP |= SCB_PCONP_PCSPI0;

  ENC28J60_Deselect ();
  ENC28J60_Reset ();

  //
  //  SPI configuration:
  //    Master mode
  //    Sample on 1st edge of SCK
  //    SCK is active high
  //    MSB out first
  //    No interrupts
  //
  SPI_SPCR = SPI_SPCR_MSTR | SPI_SPCR_CPHA1ST | SPI_SPCR_CPOLACTHIGH | SPI_SPCR_MSBF;
  
  //
  //  Reading the status register clears it
  //
  spsr = SPI_SPSR;

  //
  //  SCK0 = (PCLK = (CCLK/APB)) / 8 will be 6Mhz (putt putt putt...)
  //
  SPI_SPCCR = 8;
}

//
//
//
u8_t spiPut (u8_t valueIn)
{
  SPI_SPDR = valueIn;

  while (!(SPI_SPSR & SPI_SPSR_SPIF))
    ;

  return SPI_SPDR;
}
